@@ -3,7 +3,7 @@ package Class::DBI::ViewLoader::Pg;
 use strict;
 use warnings;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 =head1 NAME
 
@@ -11,7 +11,12 @@ Class::DBI::ViewLoader::Pg - Class::DBI::Viewloader implementation for Postgresq
 
 =head1 SYNOPSIS
 
-See L<Class::DBI::ViewLoader>
+    use Class::DBI::ViewLoader;
+
+    $loader = Class::DBI::ViewLoader dsn => 'dbi:Pg:dbname=mydb';
+
+    # load views from mydb
+    @classes = $loader->load_views
 
 =head1 DESCRIPTION
 
@@ -27,7 +32,8 @@ use base qw( Class::DBI::ViewLoader );
 
 =head2 base_class
 
-Causes generated classes to inherit from Class::DBI::Pg.
+Returns 'Class::DBI::Pg'. This class will be used as the main base class for all
+classes generated using this driver.
 
 =cut
 
@@ -35,7 +41,9 @@ sub base_class { 'Class::DBI::Pg' };
 
 =head2 get_views
 
-See L<Class::DBI::ViewLoader> for a description of this method.
+    @views = $obj->get_views
+
+Returns a list of the names of the views in the current database.
 
 =cut
 
@@ -44,22 +52,22 @@ sub get_views {
     my $dbh = $self->_get_dbi_handle;
 
     return $dbh->tables(
-	    undef,	    # catalog
-	    "public",   # schema
-	    "",	    # name
-	    "view",	    # type
+	    undef,	# catalog
+	    "public",	# schema
+	    "",		# name
+	    "view",	# type
 	    { noprefix => 1, pg_noprefix => 1 }
 	);
 }
 
-
 =head2 get_view_cols
 
-See L<Class::DBI::ViewLoader> for a description of this method.
+    @cols = $obj->get_view_cols($view)
+
+Returns the columns contained in the given view.
 
 =cut
 
-# cribbed from Class::DBI::Pg->set_up_table
 sub get_view_cols {
     my($self, $view) = @_;
     my $sth = $self->_get_cols_sth;
@@ -68,13 +76,12 @@ sub get_view_cols {
 
     my @columns = map {$_->[0]} @{$sth->fetchall_arrayref};
 
-    # warn "Got ". @columns ." column".(@columns==1?'':'s')." from $view\n";
-
     $sth->finish;
 
     return grep { !/^\.+pg\.dropped\.\d+\.+$/ } @columns;
 }
 
+# SQL to get columns cribbed from Class::DBI::Pg->set_up_table
 my $col_sql = <<END_SQL;
 SELECT a.attname
 FROM pg_catalog.pg_class c
@@ -84,22 +91,29 @@ WHERE c.relname = ?
 ORDER BY a.attnum
 END_SQL
 
+# cache the statement handle 
 sub _get_cols_sth {
     my $self = shift;
 
-    # keep this in one place
-    my $key = '__col_sth';
-
-    if(defined $self->{$key}) {
-	return $self->{$key};
+    if (defined $self->{__col_sth}) {
+	return $self->{__col_sth};
     }
     else {
 	my $dbh = $self->_get_dbi_handle;
 
-	return $self->{$key} = $dbh->prepare($col_sql);
+	return $self->{__col_sth} = $dbh->prepare($col_sql);
     }
 }
 
+# make sure the cache is cleared when the dbi handle is cleaned up
+sub _clear_dbi_handle {
+    my $self = shift;
+
+    delete $self->{__col_sth};
+
+    $self->SUPER::_clear_dbi_handle(@_);
+}
+
 1;
 
 __END__
@@ -120,3 +134,5 @@ This program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
 =cut
+
+vim: ts=8 sts=4 sw=4
